@@ -6,5 +6,5 @@ data_plugins = {
     "csv": csv_loader.load,
     "xlsx": xlsx_loader.load,
     "yaml": yaml_loader.load,
-    "yml": yaml_loader.load
-}
\ No newline at end of file
+    "yml": yaml_loader.load,
+}
