@@ -5,5 +5,5 @@ from . import self_returner
 returners_plugins = {
     "self": self_returner.dump,
     "file": file_returner.dump,
-    "terminal": terminal_returner.dump
-}
\ No newline at end of file
+    "terminal": terminal_returner.dump,
+}
