@@ -2,7 +2,7 @@
 TTR CLI tool
 ############
 
-TTR CLI is an example of tool built using TTR library.
+TTR CLI is a tool built using TTR library.
 
 This tool can be used to render data from various sources and either
 print results to screen or save them in output folder.
@@ -16,10 +16,10 @@ Supported arguments::
     -l,  --logging       Set logging level - "DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"; default ERROR
     -f,  --filters       Comma separated list of glob patterns to use for filtering data to render
 
-.. note:: ``--templates`` argument should be a path to folder with templates 
-    files within that folder/subfolders or path to ``.xlsx`` spreadsheet file with 
+.. note:: ``--templates`` argument should be a path to folder with templates
+    files within that folder/subfolders or path to ``.xlsx`` spreadsheet file with
     templates or path to ``.txt`` file with single template content.
-    
+
 In general case TTR CLI utility takes data file and templates location references and saves produced results in a subfolder within ``./Output/`` directory, where subfolder name has this format ``./Output/<current time><data file name>/``.
 
 Sample invocation::
@@ -45,18 +45,18 @@ import argparse
 import time
 import os
 import logging
-        
+from ttr import ttr
+
 log = logging.getLogger(__name__)
 
 
-#if run as a script, inject ttr folder in system path
+# if run as a script, inject ttr folder in system path
 if __name__ == "__main__":
     import sys
-    sys.path.insert(0, '.')
 
-from ttr import ttr
+    sys.path.insert(0, ".")
 
-__version__ = "0.3.3"
+__version__ = "0.4.0"
 ctime = time.strftime("%Y-%m-%d_%H-%M-%S")
 
 cli_help = """
@@ -70,7 +70,11 @@ Template Text Renderer CLI utility
 -f,  --filters       Comma separated list of glob patterns to use for filtering data to render
 """
 
+
 def cli_tool():
+    """
+    CLI utility tool function, accepts no argument.
+    """
     # form argparser menu:
     description_text = """{}""".format(cli_help)
 
@@ -79,9 +83,9 @@ def cli_tool():
         formatter_class=argparse.RawDescriptionHelpFormatter,
     )
     run_options = argparser.add_argument_group(description=description_text)
-    #-----------------------------------------------------------------------------
+    # -----------------------------------------------------------------------------
     # General options
-    #-----------------------------------------------------------------------------
+    # -----------------------------------------------------------------------------
     run_options.add_argument(
         "-d",
         "--data",
@@ -105,7 +109,7 @@ def cli_tool():
         "--output",
         action="store",
         dest="OUTPUT_FOLDER",
-        default='./Output/{}_{{}}/'.format(ctime),
+        default="./Output/{}_{{}}/".format(ctime),
         type=str,
         help=argparse.SUPPRESS,
     )
@@ -122,7 +126,7 @@ def cli_tool():
         "--logging",
         action="store",
         dest="LOGGING_LEVEL",
-        default='ERROR',
+        default="ERROR",
         type=str,
         help=argparse.SUPPRESS,
     )
@@ -135,28 +139,34 @@ def cli_tool():
         type=str,
         help=argparse.SUPPRESS,
     )
-    #-----------------------------------------------------------------------------
+    # -----------------------------------------------------------------------------
     # Parse arguments
-    #-----------------------------------------------------------------------------
+    # -----------------------------------------------------------------------------
     args = argparser.parse_args()
 
     # general arguments
     DATA = args.DATA  # string, OS path to data file or folder with files to process
-    TEMPLATES_LOCATION = args.TEMPLATES_LOCATION  # OS path to folder to save results into
+    TEMPLATES_LOCATION = (
+        args.TEMPLATES_LOCATION
+    )  # OS path to folder to save results into
     OUTPUT_FOLDER = args.OUTPUT_FOLDER  # output filename
     PRINT_TO_TERMINAL = args.PRINT_TO_TERMINAL
     LOGGING_LEVEL = args.LOGGING_LEVEL
     FILTERS = args.FILTERS
-    
+
     # set logging level
     try:
         logging.basicConfig(
             format="%(asctime)s.%(msecs)d [TTR %(levelname)s] %(lineno)d; %(message)s",
             datefmt="%m/%d/%Y %I:%M:%S",
-            level=getattr(logging, LOGGING_LEVEL.upper())
+            level=getattr(logging, LOGGING_LEVEL.upper()),
         )
     except Exception as e:
-        log.error("TTR:cli_tool - Failed to set logging level to '{}', error: {}".format(LOGGING_LEVEL, e))
+        log.error(
+            "TTR:cli_tool - Failed to set logging level to '{}', error: {}".format(
+                LOGGING_LEVEL, e
+            )
+        )
 
     # get data file OS path
     if os.path.isdir(DATA):
@@ -174,12 +184,13 @@ def cli_tool():
                 print("{}: {}".format(position, item))
             # get file number to work with
             file_number = -1
-            while not(0 <= file_number <= len(data_files) - 1):
+            while not 0 <= file_number <= len(data_files) - 1:
                 try:
                     file_number = int(input("Choose data file to work with (number): "))
                 except KeyboardInterrupt:
                     raise SystemExit()
-                except:
+                except Exception as e:
+                    log.error("Wrong choice, error: {}".format(e))
                     continue
         # form path to data file
         data_file_path = os.path.join(DATA, data_files[file_number])
@@ -190,25 +201,20 @@ def cli_tool():
         return
 
     if not PRINT_TO_TERMINAL and not os.path.exists(OUTPUT_FOLDER):
-        OUTPUT_FOLDER = OUTPUT_FOLDER.format(
-            os.path.split(data_file_path)[-1]
-        )
+        OUTPUT_FOLDER = OUTPUT_FOLDER.format(os.path.split(data_file_path)[-1])
         os.makedirs(OUTPUT_FOLDER)
 
     # generate results and save them in output folder or print to screen
     with ttr(
-            data=data_file_path,
-            templates=TEMPLATES_LOCATION,
-            returner="terminal" if PRINT_TO_TERMINAL else "file",
-            returner_kwargs={
-                "result_dir": OUTPUT_FOLDER
-            },
-            processors=["multitemplate", "filtering", "templates_split"],
-            processors_kwargs={
-                "filters": [i.strip() for i in FILTERS.split(",")]
-            }
+        data=data_file_path,
+        templates=TEMPLATES_LOCATION,
+        returner="terminal" if PRINT_TO_TERMINAL else "file",
+        returner_kwargs={"result_dir": OUTPUT_FOLDER},
+        processors=["multitemplate", "filtering", "templates_split"],
+        processors_kwargs={"filters": [i.strip() for i in FILTERS.split(",")]},
     ) as g:
         g.run()
 
+
 if __name__ == "__main__":
     cli_tool()
